@@ -2,7 +2,8 @@
 #' in order to see a list of GWAS.
 #' 
 #' @param url A url to HaploReg.
-#' Default: <http://archive.broadinstitute.org/mammals/haploreg/haploreg.php>
+#' Default: <http://pubs.broadinstitute.org/mammals/haploreg/haploreg.php>
+#' Previously was: <http://archive.broadinstitute.org/mammals/haploreg/haploreg.php>
 #' @return A list of studies. Each study is itself a list
 #' of two: \code{name}, \code{id}.
 #' @examples
@@ -11,7 +12,7 @@
 #' @rdname haploR-getStudyList
 #' @export
 getStudyList <- function(
-url="http://archive.broadinstitute.org/mammals/haploreg/haploreg.php") {
+url=Haploreg.settings[["study.url"]]) {
   
     doc.html <- htmlTreeParse(url, useInternalNodes = TRUE)
   
